@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2016-08-24'; # DATE
-our $VERSION = '1.009'; # VERSION
+our $DATE = '2016-08-26'; # DATE
+our $VERSION = '1.010'; # VERSION
 
 1;
 # ABSTRACT: A benchmark framework
@@ -18,7 +18,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 1.009 of Bencher (from Perl distribution Bencher), released on 2016-08-24.
+This document describes version 1.010 of Bencher (from Perl distribution Bencher), released on 2016-08-26.
 
 =head1 SYNOPSIS
 
@@ -316,10 +316,17 @@ From DefHash, longer description in Markdown.
 Precision to pass to Benchmark::Dumb. Default is 0. Can be overriden via
 C<--precision> (CLI).
 
+=item * with_args_size (bool)
+
+Show the size of the item code's arguments. Size is measured using
+L<Devel::Size>. The measurement is done once per item when it is testing the
+code. See also: C<with_result_size>.
+
 =item * with_result_size (bool)
 
 Show the size of the item code's return value. Size is measured using
-L<Devel::Size>. The measurement is done once per item when it is testing the.
+L<Devel::Size>. The measurement is done once per item when it is testing the
+code. See also: C<with_args_size>.
 
 =item * with_process_size (bool)
 
